#!/usr/bin/env bash

action() {

    # law + luigi env variables
    local base="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
    export LAW_HOME="$base/.law"
    export LAW_CONFIG_FILE="$base/law.cfg"
    export LUIGI_CONFIG_PATH="$base/luigi.cfg"
    export ANALYSIS_PATH="$base"
    export ANALYSIS_DATA_PATH="$ANALYSIS_PATH/data"

    # luigi + law
    export PATH="$base/law/bin:$base/luigi/bin:$PATH"
    export PYTHONPATH="$base/law:$base/luigi:$base/six:$base/python-dateutil-2.8.2:$base:$PYTHONPATH"

    # grid storage, if required
    # gfal2, not required for plotting
    # SLC6
    # source /cvmfs/grid.cern.ch/emi3ui-latest/etc/profile.d/setup-ui-example.sh
    # C7
    # source /cvmfs/grid.cern.ch/centos7-ui-v03/etc/profile.d/setup-c7-ui-example.sh
    # source /cvmfs/grid.cern.ch/umd-c7ui-latest/etc/profile.d/setup-c7-ui-example.sh
    #
    # Proxy location on afs required by lxplus if using grid storage
    # export X509_USER_PROXY=/afs/cern.ch/user/k/krabbert/tmp/x509up_u7747

    # fastNLO tools (perl and python scripts)
    # Required to merge fastwarm results or for plotting (needs python3, matplotlib3, numpy, scipy)
    # Add local paths to git checkout, e.g.
    gitpath="/storage/9/rabbertz/git/fastNLO"
    #gitpath="/eos/theory/project/applfast/git/fastNLO"
    export PATH="$gitpath/tools:$gitpath/tools/plotting:$PATH"

    # fastNLO installation (local)
    # If grid install is too old or uses fastNLO extension compiled with python2
    # !!! Does not work on systems of ETP portals or lxplus with Centos7!
    # --> Either use your more modern Desktop PC e.g. with Ubuntu and properly set PATH and PYTHONPATH
    # --> or use install with lcg software stack from /cvmfs/sft.cern.ch/lcg/views
    # Here, lcg environment and PATH, PYTHONPATH are set from local installation file
    fnlopath="/storage/9/rabbertz/local.lcg101.py3"
    #fnlopath="/eos/theory/project/applfast/local.py3"
    source $fnlopath/src/lcg_source.sh      # LCG software stack
    source $fnlopath/src/fnlosrc_source.sh  # fastNLO
    source $fnlopath/src/rivetenv.sh        # Rivet

    # NNLOJET + APPLfast
    # Uses grid install; does not use fastNLO extension compiled with python2
    applfastpath="/cvmfs/etp.kit.edu/fastnnlo-bridge-0.0.46"
    #applfastpath="/eos/theory/project/applfast/local"
    # source $applfastpath/src/fnlosrc_source_NNLOJET_rev5918.sh
    # If fastNLO version of grid install in /cvmfs/etp.kit.edu not new enough for evaluation,
    # then use local install as for plotting, but keep scripts of NNLOJET in PATH
    export PATH="$applfastpath/src/NNLOJET_rev5918/driver/bin:$PATH"

    # Output path for local production output on lxplus; not required when using grid storage
    #export ANALYSIS_OUTPUT_PATH="$applfastpath/output"

    source "$( law completion )"
}
action
